PhoenixKitWarehouse.InternalOrder (PhoenixKitWarehouse v0.5.0)

Copy Markdown View Source

Summary

Functions

Changeset for creating/editing draft internal orders.

The character varying(N) widths PhoenixKitWarehouse.Migrations builds its CREATE TABLE DDL from — the single source of truth so the migration chain, this schema, and core's ExpectedSchema manifest can never independently disagree on a number.

Changeset for correcting a posted internal order (note only — no line edits after posting).

Changeset for posting an internal order (programmatic fields only — no cast).

Changeset for soft-deleting an internal order.

Types

t()

@type t() :: %PhoenixKitWarehouse.InternalOrder{
  __meta__: term(),
  created_by_uuid: term(),
  deleted_at: term(),
  deleted_by_uuid: term(),
  inserted_at: term(),
  lines: term(),
  location_uuid: term(),
  note: term(),
  number: term(),
  performed_by_uuid: term(),
  posted_at: term(),
  source_refs: term(),
  status: term(),
  updated_at: term(),
  uuid: term()
}

Functions

changeset(order, attrs)

Changeset for creating/editing draft internal orders.

column_widths()

@spec column_widths() :: %{required(atom()) => pos_integer()}

The character varying(N) widths PhoenixKitWarehouse.Migrations builds its CREATE TABLE DDL from — the single source of truth so the migration chain, this schema, and core's ExpectedSchema manifest can never independently disagree on a number.

correction_changeset(order, attrs)

Changeset for correcting a posted internal order (note only — no line edits after posting).

post_changeset(order, performed_by_uuid)

Changeset for posting an internal order (programmatic fields only — no cast).

soft_delete_changeset(order, attrs)

Changeset for soft-deleting an internal order.

statuses()